import * as React from 'react';
import { WithThemeProps } from '../../util/enhancers/WithTheme';
export declare type BorderStyle = 'dashed' | 'dotted' | 'double' | 'groove' | 'hidden' | 'inset' | 'none' | 'outset' | 'ridge' | 'solid';
export interface BorderProps {
    /** The border style of the border. Ex: '1px solid black' */
    border?: string;
    /** The border-style of the border. 'solid' for example. */
    borderStyle?: BorderStyle;
    /** The width of the border. */
    width?: number;
    /** The color of the border. */
    color?: string;
    /** Sets flex on style. */
    flex?: number;
    /** The border radius of the border. */
    borderRadius?: string;
    /** The top left border radius of the border. */
    borderTopLeftRadius?: string;
    /** The top right border radius of the border. */
    borderTopRightRadius?: string;
    /** The bottom left border radius of the border. */
    borderBottomLeftRadius?: string;
    /** The bottom right border radius of the border. */
    borderBottomRightRadius?: string;
    /** Custom style of the div that has the border. */
    style?: React.CSSProperties;
    /** Add border to the top. */
    top?: boolean;
    /** Add border to the bottom. */
    bottom?: boolean;
    /** Add border to the left. */
    left?: boolean;
    /** Add border to the right. */
    right?: boolean;
    /** Sets overflow of the border div. */
    overflow?: 'auto' | 'hidden' | 'scroll' | 'visible';
    /** Class name on the border div */
    className?: string;
}
export declare class BorderComponent extends React.Component<BorderProps & WithThemeProps> {
    render(): JSX.Element;
}
export declare const Border: React.ComponentClass<BorderProps, any>;
