"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var date_fns_1 = require("date-fns");
var _ = require("lodash");
var React = require("react");
var recompose_1 = require("recompose");
var layout_1 = require("../../../layout");
var CalendarDataFactory_1 = require("../util/CalendarDataFactory");
var CalendarMonth_1 = require("./CalendarMonth");
var CalendarTheme_1 = require("./CalendarTheme");
var CalendarDay_1 = require("./renderers/CalendarDay");
var CalendarComponent = function (_a) {
    var year = _a.year, monthRows = _a.monthRows, _b = _a.dayComponent, dayComponent = _b === void 0 ? CalendarDay_1.CalendarDay : _b, userDataPerMonth = _a.userDataPerMonth, statePerMonth = _a.statePerMonth, onClickDay = _a.onClickDay, onClickWeekDay = _a.onClickWeekDay, onClickWeek = _a.onClickWeek, renderWeekDay = _a.renderWeekDay, renderWeekNumber = _a.renderWeekNumber, headerLeftContent = _a.headerLeftContent, headerRightContent = _a.headerRightContent, extraDayContent = _a.extraDayContent, defaultHighlights = _a.defaultHighlights, _c = _a.theme, theme = _c === void 0 ? CalendarTheme_1.defaultCalendarTheme : _c;
    return (React.createElement("div", null, monthRows.map(function (monthRow, rowIndex) { return (React.createElement(layout_1.Spacing, { key: rowIndex },
        React.createElement(layout_1.Row, null, monthRow.map(function (month, index) { return (React.createElement(React.Fragment, { key: month.name },
            index > 0 && React.createElement(layout_1.Space, null),
            React.createElement(CalendarMonth_1.CalendarMonth, { month: month, dayComponent: dayComponent, userDataPerWeek: userDataPerMonth && userDataPerMonth[month.monthString], statePerWeek: statePerMonth && statePerMonth[month.monthString], onClickDay: onClickDay, onClickWeekDay: onClickWeekDay, onClickWeek: onClickWeek, theme: theme, renderWeekNumber: renderWeekNumber, renderWeekDay: renderWeekDay, headerLeftContent: headerLeftContent, headerRightContent: headerRightContent, extraDayContent: extraDayContent, defaultHighlights: defaultHighlights }))); })))); })));
};
var applyDefaultDates = function () {
    return recompose_1.mapProps(function (props) {
        var month = props.month, year = props.year, date = props.date;
        if (month && year) {
            return tslib_1.__assign({}, props, { month: month,
                year: year });
        }
        if (date) {
            return tslib_1.__assign({}, props, { month: date_fns_1.getMonth(date), year: date_fns_1.getYear(date) });
        }
        var now = new Date();
        return tslib_1.__assign({}, props, { month: date_fns_1.getMonth(now), year: date_fns_1.getYear(now) });
    });
};
var handleOverflowingMonth = function () {
    return recompose_1.withProps(function (_a) {
        var month = _a.month, year = _a.year;
        return CalendarDataFactory_1.calculateOverflowingMonth(year, month);
    });
};
var createCalendarMonths = function () {
    return recompose_1.withProps(function (_a) {
        var numMonths = _a.numMonths, monthsPerRow = _a.monthsPerRow, year = _a.year, month = _a.month;
        if (numMonths == null) {
            return {
                monthRows: [[CalendarDataFactory_1.getMonthInYear(year, month)]],
            };
        }
        if (monthsPerRow == null) {
            return {
                monthRows: [CalendarDataFactory_1.getMonthsInYear(year, month, numMonths)],
            };
        }
        return {
            monthRows: _.chunk(CalendarDataFactory_1.getMonthsInYear(year, month, numMonths), monthsPerRow),
        };
    });
};
exports.createCalendar = function () {
    return recompose_1.compose(applyDefaultDates(), handleOverflowingMonth(), createCalendarMonths())(CalendarComponent);
};
//# sourceMappingURL=Calendar.js.map