import { CSSProperties } from 'react';
import { ButtonTheme } from '../../../buttons/ButtonTheme';
import { DefaultTextProps } from '../../../text/DefaultText';
import { DayState, DayStateHighlight } from '../types/CalendarTypes';
import { DayData, MonthData, WeekData } from '../util/CalendarDataFactory';
export interface CalendarTheme<TUserData = {}> {
    width: string;
    height: string;
    WeekNumber: WeekNumberTheme;
    WeekDay: WeekDayTheme;
    CalendarDay: CalendarDayTheme<TUserData>;
    CalendarMonth: CalendarMonthTheme;
}
export interface WeekNumberTheme {
    backgroundColor: string;
    textColor?: string;
}
export interface SwitchButtonTheme extends ButtonTheme {
    height?: string;
    width?: string;
}
export interface CalendarMonthTheme {
    headerTextColor?: string;
    SwitchButton?: SwitchButtonTheme;
}
export interface WeekDayTheme {
    textColor?: string;
}
declare type CalendarStyleProvider<TUserData, TResult> = (defaultHighlights: Array<DayStateHighlight> | undefined, dayState: DayState | undefined, day: DayData, week: WeekData, month: MonthData, userData?: TUserData) => TResult;
declare type WrapperStyleProvider<TUserData> = CalendarStyleProvider<TUserData, CSSProperties | undefined>;
declare type TextPropsProvider<TUserData> = CalendarStyleProvider<TUserData, DefaultTextProps | undefined>;
export interface CalendarDayTheme<TUserData> {
    wrapperStyle?: WrapperStyleProvider<TUserData>;
    innerWrapperStyle?: WrapperStyleProvider<TUserData>;
    cellWrapperStyle?: WrapperStyleProvider<TUserData>;
    textProps?: TextPropsProvider<TUserData>;
}
interface DefaultWrapperColors {
    selectedBorder: string;
    selectedBackground: string;
    rangeBorder: string;
    rangeBackground: string;
    todayBorder: string;
    todayBackground: string;
}
export declare const defaultWrapperStyleProvider: ({ selectedBackground, todayBackground, rangeBackground, selectedBorder, rangeBorder, todayBorder, }: DefaultWrapperColors) => CalendarStyleProvider<{}, CSSProperties | undefined>;
interface DefaultTextColors {
    disabledColor: string;
    inOtherMonthColor: string;
    selectedColor: string;
}
export declare const defaultTextPropsProvider: ({ selectedColor, disabledColor, inOtherMonthColor, }: DefaultTextColors) => CalendarStyleProvider<{}, DefaultTextProps | undefined>;
export declare const defaultCalendarTheme: CalendarTheme;
export declare const extranetCalendarTheme: CalendarTheme;
export {};
