"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var DefaultColors_1 = require("../../../../../themes/default-values/DefaultColors");
var ButtonTheme_1 = require("../../../buttons/ButtonTheme");
var StateHelper_1 = require("../util/StateHelper");
exports.defaultWrapperStyleProvider = function (_a) {
    var selectedBackground = _a.selectedBackground, todayBackground = _a.todayBackground, rangeBackground = _a.rangeBackground, selectedBorder = _a.selectedBorder, rangeBorder = _a.rangeBorder, todayBorder = _a.todayBorder;
    return function (defaultHighlights, dayState, day, week, month) {
        var backgroundColor = StateHelper_1.dayHighlightSelect(dayState, defaultHighlights, ['selected', 'today', 'range', day.month === month.monthInYear], [selectedBackground, todayBackground, rangeBackground, DefaultColors_1.defaultColors.white], 'transparent');
        if (day.month === month.monthInYear) {
            return {
                backgroundColor: backgroundColor,
                borderWidth: '1px',
                borderColor: StateHelper_1.dayHighlightSelect(dayState, defaultHighlights, ['selected', 'range', 'today'], [selectedBorder, rangeBorder, todayBorder], DefaultColors_1.defaultColors.separatorLight),
                borderCollapse: 'collapse',
                borderStyle: StateHelper_1.dayHasHighlight(dayState, defaultHighlights, 'selected') ||
                    StateHelper_1.dayHasHighlight(dayState, defaultHighlights, 'range') ||
                    StateHelper_1.dayHasHighlight(dayState, defaultHighlights, 'today')
                    ? 'double'
                    : 'solid',
                boxSizing: 'border-box',
            };
        }
        return undefined;
    };
};
exports.defaultTextPropsProvider = function (_a) {
    var selectedColor = _a.selectedColor, disabledColor = _a.disabledColor, inOtherMonthColor = _a.inOtherMonthColor;
    return function (defaultHighlights, dayState, day, week, month) {
        var isOtherMonth = day.month !== month.monthInYear;
        var color = StateHelper_1.dayHighlightSelect(dayState, defaultHighlights, [isOtherMonth, 'selected', 'enabled', 'disabled'], [inOtherMonthColor, selectedColor, undefined, disabledColor]);
        return {
            color: color,
        };
    };
};
exports.defaultCalendarTheme = {
    width: '40px',
    height: '40px',
    WeekNumber: {
        backgroundColor: 'transparent',
    },
    WeekDay: {
        textColor: DefaultColors_1.defaultColors.separator,
    },
    CalendarDay: {
        wrapperStyle: exports.defaultWrapperStyleProvider({
            selectedBorder: DefaultColors_1.defaultColors.inputBorderFocused,
            selectedBackground: DefaultColors_1.defaultColors.inputBorderFocused,
            rangeBorder: DefaultColors_1.defaultColors.inputBorderFocusedAlt,
            rangeBackground: DefaultColors_1.defaultColors.inputBorderFocusedLight,
            todayBorder: DefaultColors_1.defaultColors.highlightBoxBorder,
            todayBackground: DefaultColors_1.defaultColors.highlightBoxBg,
        }),
        textProps: exports.defaultTextPropsProvider({
            selectedColor: DefaultColors_1.defaultColors.white,
            disabledColor: DefaultColors_1.defaultColors.disabledText,
            inOtherMonthColor: 'transparent',
        }),
    },
    CalendarMonth: {
        SwitchButton: tslib_1.__assign({}, ButtonTheme_1.defaultButtonTheme),
    },
};
exports.extranetCalendarTheme = {
    width: '37px',
    height: '37px',
    WeekNumber: {
        backgroundColor: 'transparent',
    },
    WeekDay: {
        textColor: DefaultColors_1.defaultColors.separator,
    },
    CalendarDay: {
        wrapperStyle: exports.defaultWrapperStyleProvider({
            selectedBorder: '#2A7EC5',
            selectedBackground: '#2A7EC5',
            rangeBorder: '#DAE7F2',
            rangeBackground: '#E2EDF7',
            todayBorder: '#60BD2F',
            todayBackground: '#F1F9ED',
        }),
        textProps: exports.defaultTextPropsProvider({
            selectedColor: DefaultColors_1.defaultColors.white,
            disabledColor: DefaultColors_1.defaultColors.disabledText,
            inOtherMonthColor: 'transparent',
        }),
    },
    CalendarMonth: {
        SwitchButton: tslib_1.__assign({}, ButtonTheme_1.defaultButtonTheme, { bgColor: '#2A7EC5', textColor: '#FFFFFF', borderRadius: '4px', width: '26px' }),
    },
};
//# sourceMappingURL=CalendarTheme.js.map