"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var date_fns_1 = require("date-fns");
var recompose_1 = require("recompose");
var CalendarIntervalValidator_1 = require("../util/CalendarIntervalValidator");
var StateModifier_1 = require("../util/StateModifier");
var withOnClickDayHandler = recompose_1.withHandlers({
    onClickDay: function (_a) {
        var focusedInput = _a.focusedInput, endDate = _a.endDate, startDate = _a.startDate, setStartDate = _a.setStartDate, setEndDate = _a.setEndDate, onChange = _a.onChange, setFocusedInput = _a.setFocusedInput;
        return function (day) {
            if (focusedInput === 'startDate') {
                if (endDate && date_fns_1.isAfter(day.date, endDate)) {
                    setStartDate(endDate);
                    setEndDate(day.date);
                    if (onChange) {
                        onChange({ startDate: endDate, endDate: day.date });
                    }
                }
                else {
                    setStartDate(day.date);
                    setFocusedInput('endDate');
                    if (onChange) {
                        onChange(CalendarIntervalValidator_1.ensureStartIsFirst({
                            startDate: day.date,
                            endDate: endDate,
                        }));
                    }
                }
            }
            else if (focusedInput === 'endDate') {
                if (startDate && date_fns_1.isAfter(startDate, day.date)) {
                    setStartDate(day.date);
                    setEndDate(startDate);
                    if (onChange) {
                        onChange({ startDate: day.date, endDate: startDate });
                    }
                }
                else {
                    setEndDate(day.date);
                    setFocusedInput('startDate');
                    if (onChange) {
                        onChange(CalendarIntervalValidator_1.ensureStartIsFirst({
                            startDate: startDate,
                            endDate: day.date,
                        }));
                    }
                }
            }
        };
    },
});
var toggleDatesIfEndIsEarlierThanStart = recompose_1.withProps(function (_a) {
    var startDate = _a.startDate, endDate = _a.endDate;
    if (startDate && endDate && date_fns_1.isAfter(startDate, endDate)) {
        return {
            startDate: endDate,
            endDate: startDate,
        };
    }
    return {};
});
var withStatePerMonth = recompose_1.withProps(function (_a) {
    var startDate = _a.startDate, endDate = _a.endDate, statePerMonth = _a.statePerMonth;
    return ({
        statePerMonth: exports.buildDayState(statePerMonth, startDate, endDate),
    });
});
exports.buildDayState = function (statePerMonth, start, end) {
    if (statePerMonth === void 0) { statePerMonth = {}; }
    if (start && end) {
        return date_fns_1.eachDayOfInterval({ start: start, end: end }).reduce(function (result, date) {
            var isFirstInRange = date_fns_1.isSameDay(date, start);
            var isLastInRange = date_fns_1.isSameDay(date, end);
            return StateModifier_1.addDayStateHighlights(result, date, isFirstInRange || isLastInRange ? ['selected', 'range'] : ['range']);
        }, statePerMonth);
    }
    if (start) {
        return StateModifier_1.addDayStateHighlights(statePerMonth, start, ['selected']);
    }
    if (end) {
        return StateModifier_1.addDayStateHighlights(statePerMonth, end, ['selected']);
    }
    return statePerMonth;
};
exports.withDateRangeSelectionState = recompose_1.compose(recompose_1.withState('startDate', 'setStartDate', undefined), recompose_1.withState('endDate', 'setEndDate', undefined), recompose_1.withState('focusedInput', 'setFocusedInput', 'startDate'));
exports.withDateRangeSelection = recompose_1.compose(withOnClickDayHandler, toggleDatesIfEndIsEarlierThanStart, recompose_1.pure, withStatePerMonth);
//# sourceMappingURL=DateRangeSelection.js.map