"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var recompose_1 = require("recompose");
var CalendarDataFactory_1 = require("../util/CalendarDataFactory");
var StateModifier_1 = require("../util/StateModifier");
var addSelectionLogic = recompose_1.withHandlers({
    onClickDay: function (_a) {
        var onChange = _a.onChange;
        return function (day) {
            if (onChange) {
                onChange(getWeekStringFromWeekData(CalendarDataFactory_1.getWeekForDate(day.date)));
            }
        };
    },
    onClickWeek: function (_a) {
        var onChange = _a.onChange;
        return function (week) {
            if (onChange) {
                onChange(getWeekStringFromWeekData(week));
            }
        };
    },
});
var buildSelectionState = recompose_1.withProps(function (_a) {
    var value = _a.value, statePerMonth = _a.statePerMonth;
    var weekData = getWeekDataFromWeekString(value);
    return {
        statePerMonth: weekData
            ? StateModifier_1.addWeekStateHighlights(statePerMonth, weekData, ['selected'])
            : statePerMonth,
        date: value,
        startDateInFocus: value,
    };
});
var getWeekStringFromWeekData = function (week) {
    if (!week) {
        return undefined;
    }
    return week.endYear + "-" + week.weekNumber;
};
var getWeekDataFromWeekString = function (week) {
    if (!week) {
        return undefined;
    }
    var parts = week.split('-');
    var weekNumber = parseInt(parts[1], 10);
    var year = parseInt(parts[0], 10);
    return CalendarDataFactory_1.getWeekForDate(CalendarDataFactory_1.getStartDateOfISOWeek(weekNumber, year));
};
exports.withSingleWeekSelection = recompose_1.compose(addSelectionLogic, recompose_1.pure, buildSelectionState);
//# sourceMappingURL=SingleWeekSelection.js.map