"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var date_fns_1 = require("date-fns");
var DateFormats_1 = require("../../../../../util/date/DateFormats");
var Months;
(function (Months) {
    Months[Months["JANUARY"] = 0] = "JANUARY";
    Months[Months["FEBRUARY"] = 1] = "FEBRUARY";
    Months[Months["MARCH"] = 2] = "MARCH";
    Months[Months["APRIL"] = 3] = "APRIL";
    Months[Months["MAY"] = 4] = "MAY";
    Months[Months["JUNE"] = 5] = "JUNE";
    Months[Months["JULY"] = 6] = "JULY";
    Months[Months["AUGUST"] = 7] = "AUGUST";
    Months[Months["SEPTEMBER"] = 8] = "SEPTEMBER";
    Months[Months["OCTOBER"] = 9] = "OCTOBER";
    Months[Months["NOVEMBER"] = 10] = "NOVEMBER";
    Months[Months["DECEMBER"] = 11] = "DECEMBER";
})(Months = exports.Months || (exports.Months = {}));
var WeekDays;
(function (WeekDays) {
    WeekDays[WeekDays["SUNDAY"] = 0] = "SUNDAY";
    WeekDays[WeekDays["MONDAY"] = 1] = "MONDAY";
    WeekDays[WeekDays["TUESDAY"] = 2] = "TUESDAY";
    WeekDays[WeekDays["WEDNESDAY"] = 3] = "WEDNESDAY";
    WeekDays[WeekDays["THURSDAY"] = 4] = "THURSDAY";
    WeekDays[WeekDays["FRIDAY"] = 5] = "FRIDAY";
    WeekDays[WeekDays["SATURDAY"] = 6] = "SATURDAY";
})(WeekDays = exports.WeekDays || (exports.WeekDays = {}));
exports.getMonthsInYear = function (year, startMonth, numMonths) {
    var months = [];
    for (var i = 0; i < numMonths; i++) {
        months.push(exports.getMonthInYear(year, startMonth + i));
    }
    return months;
};
exports.getMonthInYear = function (year, month) {
    var yearToUse = year + Math.floor(month / 12);
    var monthToUse = month % 12;
    var firstDayOfMonth = new Date(yearToUse, monthToUse, 1);
    return {
        monthString: date_fns_1.format(firstDayOfMonth, DateFormats_1.DateFormats.yearAndMonth),
        name: date_fns_1.format(firstDayOfMonth, DateFormats_1.DateFormats.fullMonthName),
        year: yearToUse,
        monthInYear: monthToUse,
        weeks: exports.getWeeksForMonth(yearToUse, monthToUse),
    };
};
exports.getWeeksForMonth = function (year, month, forceSixWeeks) {
    if (forceSixWeeks === void 0) { forceSixWeeks = true; }
    var firstDayOfMonth = new Date(year, month, 1);
    var firstDayOfFirstWeek = date_fns_1.startOfISOWeek(firstDayOfMonth);
    var weeks = [];
    for (var i = 0; i < 6; i++) {
        var week = exports.getWeekForDate(date_fns_1.addWeeks(firstDayOfFirstWeek, i));
        if (i > 0 && week.startMonth !== month && !forceSixWeeks) {
            return weeks;
        }
        weeks.push(week);
    }
    return weeks;
};
exports.getWeekForDate = function (firstDayOfWeek) {
    var isLastWeekOfMonth = date_fns_1.getMonth(date_fns_1.addDays(firstDayOfWeek, 7)) !== date_fns_1.getMonth(firstDayOfWeek);
    return {
        weekNumber: date_fns_1.getISOWeek(firstDayOfWeek),
        startMonth: date_fns_1.getMonth(firstDayOfWeek),
        startYear: date_fns_1.getYear(firstDayOfWeek),
        endMonth: date_fns_1.getMonth(date_fns_1.addDays(firstDayOfWeek, 6)),
        endYear: date_fns_1.getYear(date_fns_1.addDays(firstDayOfWeek, 6)),
        days: exports.getDaysForWeekForDate(firstDayOfWeek),
        isLastWeekOfMonth: isLastWeekOfMonth,
    };
};
exports.createDay = function (date) {
    var dayOfWeek = date_fns_1.getISODay(date);
    return {
        date: date,
        name: date_fns_1.format(date, 'EEE'),
        dateString: date_fns_1.format(date_fns_1.addHours(date, 12), DateFormats_1.DateFormats.fullDate),
        weekNumber: date_fns_1.getISOWeek(date),
        year: date_fns_1.getYear(date),
        month: date_fns_1.getMonth(date),
        dayOfMonth: date_fns_1.getDate(date),
        dayOfWeek: dayOfWeek,
        isFirstDayOfWeek: dayOfWeek === 1,
        isLastDayOfWeek: dayOfWeek === 7,
        isFirstDayOfMonth: date_fns_1.isSameDay(date_fns_1.startOfMonth(date), date),
        isLastDayOfMonth: date_fns_1.isSameDay(date_fns_1.endOfMonth(date), date),
    };
};
exports.getDaysForWeekForDate = function (firstDayOfWeek) {
    return date_fns_1.eachDayOfInterval({
        start: firstDayOfWeek,
        end: date_fns_1.addDays(firstDayOfWeek, 6),
    }).map(exports.createDay);
};
exports.getStartDateOfISOWeek = function (weekNumber, year) {
    var simple = new Date(year, 0, 1 + (weekNumber - 1) * 7);
    var dayOfWeek = simple.getDay();
    var isoWeekStart = simple;
    if (dayOfWeek <= 4) {
        isoWeekStart.setDate(simple.getDate() - simple.getDay() + 1);
    }
    else {
        isoWeekStart.setDate(simple.getDate() + 8 - simple.getDay());
    }
    return isoWeekStart;
};
exports.calculateOverflowingMonth = function (year, month) {
    if (month > Months.DECEMBER) {
        return { year: year + Math.floor(month / 12), month: month % 12 };
    }
    if (month < Months.JANUARY) {
        return { year: year + Math.floor(month / 12), month: 12 + (month % 12) };
    }
    return { year: year, month: month };
};
//# sourceMappingURL=CalendarDataFactory.js.map