"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var date_fns_1 = require("date-fns");
var React = require("react");
var recompose_1 = require("recompose");
var DateFormats_1 = require("../../../../util/date/DateFormats");
var enhancers_1 = require("../../../util/enhancers");
var colors_1 = require("../../colors");
var decorations_1 = require("../../decorations");
var layout_1 = require("../../layout");
var overlay_1 = require("../../overlay");
var positioning_1 = require("../../positioning");
var text_1 = require("../../text");
var DateRangeCalendar_1 = require("../calendar/DateRangeCalendar");
var text_input_1 = require("../text-input");
// tslint:disable:no-empty
var noop = function () { };
var DateRangeInputComponent = function (_a) {
    var showCalendarStartDate = _a.showCalendarStartDate, showCalendarEndDate = _a.showCalendarEndDate, hideCalendar = _a.hideCalendar, displayFormat = _a.displayFormat, showingCalendar = _a.showingCalendar, showingFocusHighlight = _a.showingFocusHighlight, placeholderStartDate = _a.placeholderStartDate, placeholderEndDate = _a.placeholderEndDate, onSelectDateRange = _a.onSelectDateRange, value = _a.value, zIndex = _a.zIndex, setStartDate = _a.setStartDate, setEndDate = _a.setEndDate, focusedInput = _a.focusedInput, setFocusedInput = _a.setFocusedInput, _b = _a.toText, toText = _b === void 0 ? 'to' : _b, theme = _a.theme;
    return (React.createElement(layout_1.Column, null,
        React.createElement(layout_1.Row, { alignItems: 'center' },
            React.createElement(text_input_1.DefaultTextInput, { iconLeft: 'calendar-alt', onFocus: showCalendarStartDate, forceFocusHighlight: focusedInput === 'startDate' && showingFocusHighlight, value: value.startDate ? date_fns_1.format(value.startDate, displayFormat) : '', placeholder: placeholderStartDate, onChange: noop, size: 9 }),
            React.createElement(layout_1.Space, null),
            React.createElement(text_1.DefaultText, null, toText),
            React.createElement(layout_1.Space, null),
            React.createElement(text_input_1.DefaultTextInput, { iconLeft: 'calendar-alt', onFocus: showCalendarEndDate, forceFocusHighlight: focusedInput === 'endDate' && showingFocusHighlight, value: value.endDate ? date_fns_1.format(value.endDate, displayFormat) : '', placeholder: placeholderEndDate, onChange: noop, size: 9 })),
        showingCalendar && (React.createElement(positioning_1.Relative, null,
            React.createElement(overlay_1.Overlay, { onClickOutside: hideCalendar, backgroundOpacity: 0 }),
            React.createElement(positioning_1.Absolute, { zIndex: zIndex },
                React.createElement(decorations_1.Border, { color: theme.components.DateRangeInput.borderColor },
                    React.createElement(colors_1.Background, { color: theme.components.DateRangeInput.backgroundColor },
                        React.createElement(layout_1.Indent, null,
                            React.createElement(DateRangeCalendar_1.DateRangeCalendar, { startDateInFocus: focusedInput === 'startDate' || focusedInput === 'endDate'
                                    ? value[focusedInput]
                                    : undefined, onChange: onSelectDateRange, startDate: value.startDate, endDate: value.endDate, setStartDate: setStartDate, setEndDate: setEndDate, focusedInput: focusedInput, setFocusedInput: setFocusedInput, theme: theme.components.DateRangeInput.calendar })))))))));
};
var withShowingCalendarState = recompose_1.compose(recompose_1.withState('showingCalendar', 'setShowingCalendar', false), recompose_1.withState('showingFocusHighlight', 'setShowingFocusHighlight', false));
var withFocusedInputState = recompose_1.withState('focusedInput', 'setFocusedInput', undefined);
var withShowCalendarHandlers = recompose_1.withHandlers({
    showCalendarStartDate: function (_a) {
        var setShowingCalendar = _a.setShowingCalendar, setShowingFocusHighlight = _a.setShowingFocusHighlight, setFocusedInput = _a.setFocusedInput;
        return function () {
            setFocusedInput('startDate');
            setShowingCalendar(true);
            setShowingFocusHighlight(true);
            return true;
        };
    },
    showCalendarEndDate: function (_a) {
        var setShowingCalendar = _a.setShowingCalendar, setShowingFocusHighlight = _a.setShowingFocusHighlight, setFocusedInput = _a.setFocusedInput;
        return function () {
            setFocusedInput('endDate');
            setShowingCalendar(true);
            setShowingFocusHighlight(true);
            return true;
        };
    },
    hideCalendar: function (_a) {
        var setShowingCalendar = _a.setShowingCalendar, setShowingFocusHighlight = _a.setShowingFocusHighlight;
        return function () {
            setShowingCalendar(false);
            setShowingFocusHighlight(false);
        };
    },
    setStartDate: function (_a) {
        var value = _a.value, onChange = _a.onChange, setShowingCalendar = _a.setShowingCalendar, setShowingFocusHighlight = _a.setShowingFocusHighlight, focusedInput = _a.focusedInput;
        return function (startDate) {
            if (onChange) {
                onChange({ startDate: startDate, endDate: value.endDate });
            }
            if (focusedInput === 'endDate') {
                setShowingFocusHighlight(false);
                setTimeout(function () { return setShowingCalendar(false); }, 150);
            }
        };
    },
    setEndDate: function (_a) {
        var value = _a.value, onChange = _a.onChange, setShowingCalendar = _a.setShowingCalendar, setShowingFocusHighlight = _a.setShowingFocusHighlight, focusedInput = _a.focusedInput;
        return function (endDate) {
            if (onChange) {
                onChange({ startDate: value.startDate, endDate: endDate });
            }
            if (focusedInput === 'endDate') {
                setShowingFocusHighlight(false);
                setTimeout(function () { return setShowingCalendar(false); }, 150);
            }
        };
    },
});
var withOnSelectDateHandler = recompose_1.withHandlers({
    onSelectDateRange: function (_a) {
        var setShowingCalendar = _a.setShowingCalendar, onChange = _a.onChange, hideCalendar = _a.hideCalendar;
        return function (dateRange) {
            if (onChange) {
                onChange(dateRange);
            }
        };
    },
});
var withDefaultProps = recompose_1.defaultProps({
    displayFormat: DateFormats_1.DateFormats.fullDate,
    placeholderStartDate: 'Start date',
    placeholderEndDate: 'End date',
    zIndex: 100,
});
exports.DateRangeInput = recompose_1.setDisplayName('DateRangeInput')(recompose_1.compose(withDefaultProps, withShowingCalendarState, withFocusedInputState, withShowCalendarHandlers, withOnSelectDateHandler, enhancers_1.withTheme)(DateRangeInputComponent));
//# sourceMappingURL=DateRangeInput.js.map