"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var recompose_1 = require("recompose");
var WithComponentTheme_1 = require("../../../util/enhancers/WithComponentTheme");
var UpDownButtons_1 = require("../../buttons/UpDownButtons");
var Border_1 = require("../../decorations/Border");
var Space_1 = require("../../layout/Space");
var DefaultTextInput_1 = require("./DefaultTextInput");
var withOnClicks = recompose_1.withHandlers({
    onClickDown: function (_a) {
        var _b = _a.value, value = _b === void 0 ? 0 : _b, onChange = _a.onChange, max = _a.max, min = _a.min, _c = _a.step, step = _c === void 0 ? 1 : _c;
        return function () {
            if (onChange) {
                var newValue = value - step;
                onChange(min != null ? Math.max(min, newValue) : newValue);
            }
        };
    },
    onClickUp: function (_a) {
        var _b = _a.value, value = _b === void 0 ? 0 : _b, onChange = _a.onChange, max = _a.max, min = _a.min, _c = _a.step, step = _c === void 0 ? 1 : _c;
        return function () {
            if (onChange) {
                var newValue = value + step;
                onChange(max != null ? Math.min(max, newValue) : newValue);
            }
        };
    },
    onChange: function (_a) {
        var onChange = _a.onChange;
        return function (value) {
            var n = parseIntOrFloat(value);
            if (n != null && !isNaN(n)) {
                onChange(n);
            }
        };
    },
});
var withUpDownButtons = recompose_1.withProps(function (_a) {
    var onClickDown = _a.onClickDown, onClickUp = _a.onClickUp, theme = _a.theme, contentRight = _a.contentRight, hideButtons = _a.hideButtons, disabled = _a.disabled;
    return ({
        contentRight: hideButtons ? (contentRight) : (React.createElement(React.Fragment, null,
            contentRight && (React.createElement(React.Fragment, null,
                contentRight,
                React.createElement(Space_1.Space, null))),
            React.createElement(Border_1.Border, { color: theme.borderColor, left: true },
                React.createElement(UpDownButtons_1.UpDownButtons, { onClickUp: disabled ? undefined : onClickUp, onClickDown: disabled ? undefined : onClickDown, buttonHeight: theme.buttonHeight, iconColor: theme.textColor })))),
        disableContentPaddingRight: true,
        inputType: 'number',
    });
});
var prepareThemeForTextInput = recompose_1.withProps(function (props) {
    var theme = props.theme;
    var _a = theme, buttonHeight = _a.buttonHeight, defaultTextInputTheme = tslib_1.__rest(_a, ["buttonHeight"]);
    return tslib_1.__assign({}, props, { theme: defaultTextInputTheme });
});
exports.NumericTextInput = recompose_1.setDisplayName('NumericTextInput')(recompose_1.compose(withOnClicks, WithComponentTheme_1.withComponentTheme('NumericTextInput'), withUpDownButtons, prepareThemeForTextInput)(DefaultTextInput_1.DefaultTextInput));
var parseIntOrFloat = function (s) {
    return hasDecimal(s) ? parseFloat(s) : parseInt(s, 10);
};
var hasDecimal = function (s) {
    return s.indexOf('.') >= 0 || s.indexOf(',') >= 0;
};
//# sourceMappingURL=NumericTextInput.js.map