import * as React from 'react';
import { CSSProperties, KeyboardEventHandler } from 'react';
declare type MoveDirection = 'right' | 'left' | 'down' | 'up';
export interface SimpleTextInputProps {
    /** The current value shown in the text input. */
    value?: string;
    /** CSS class name applied to the input element. */
    className?: string;
    /** onChange callback, called when user triggers a value change in the field. */
    onChange?: (value: string) => void;
    /** onDone callback, triggered by blur, if the blur was not triggered by esc key. */
    onDone?: (value: string) => void;
    /** onEsc callback, called user presses the escape key. */
    onEsc?: () => void;
    /** onEnter callback, called user presses the enter key. This triggers a blur. */
    onEnter?: () => void;
    /** Width of the input element. */
    width?: string;
    /** Height of the input element. */
    height?: string;
    /** If true, field will focus automatically when mounted in DOM. */
    focusOnMount?: boolean;
    /** If true, all text in the input field will be selected on mount. */
    selectAllOnMount?: boolean;
    /** If true, cursor will move to the end of the entered text on mount. */
    moveCursorToEndOnMount?: boolean;
    /** Type of input */
    inputType?: string;
    fontSize?: string;
    maxLength?: number;
    size?: number;
    min?: number;
    max?: number;
    backgroundColor?: string;
    textColor?: string;
    disabled?: boolean;
    placeholder?: string;
    placeholderColor?: string;
    style?: CSSProperties;
    onKeyDown?: KeyboardEventHandler<HTMLInputElement>;
    /** onMove callback, triggered when user tries to move outside of field using arrow keys, tab or shift+tab. */
    onMove?: (direction: MoveDirection) => void;
    onFocus?: () => void;
    onBlur?: () => void;
}
export interface SimpleTextInputState {
    wasCancelled: boolean;
}
export declare const SimpleTextInput: React.ComponentClass<SimpleTextInputProps, any>;
export {};
