"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var styled_1 = require("@emotion/styled");
var React = require("react");
var recompose_1 = require("recompose");
var WithTheme_1 = require("../../../util/enhancers/WithTheme");
var StyledInput = styled_1.default('input')(function (_a) {
    var backgroundColor = _a.backgroundColor, fontSize = _a.fontSize, height = _a.height, outerStyle = _a.outerStyle, placeholderColor = _a.placeholderColor, textColor = _a.textColor, theme = _a.theme, width = _a.width;
    return (tslib_1.__assign({ '&::placeholder': {
            color: placeholderColor || theme.components.SimpleTextInput.placeholderColor,
        }, MozAppearance: 'textfield', '&::-webkit-outer-spin-button, &::-webkit-inner-spin-button': {
            WebkitAppearance: 'none',
            margin: 0,
        }, backgroundColor: backgroundColor || theme.components.SimpleTextInput.backgroundColor, color: textColor || theme.components.SimpleTextInput.textColor, '&:disabled': {
            backgroundColor: "" + theme.components.SimpleTextInput.disabledBackgroundColor,
            color: "" + theme.components.SimpleTextInput.disabledTextColor,
        }, height: height || theme.components.SimpleTextInput.height, width: width || '100%', fontSize: fontSize || theme.components.SimpleTextInput.fontSize, fontFamily: theme.components.SimpleTextInput.fontFamily }, outerStyle));
});
var SimpleTextInputComponent = /** @class */ (function (_super) {
    tslib_1.__extends(SimpleTextInputComponent, _super);
    function SimpleTextInputComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            wasCancelled: false,
        };
        _this.textInput = React.createRef();
        _this.onChange = function (_a) {
            var target = _a.target;
            var onChange = _this.props.onChange;
            var value = target.value;
            if (onChange) {
                onChange(value || '');
            }
        };
        _this.onKeyDown = function (e) {
            var _a = _this.props, onEsc = _a.onEsc, onEnter = _a.onEnter, onKeyDown = _a.onKeyDown, onMove = _a.onMove;
            var key = e.key;
            if (key === 'Enter') {
                _this.textInput.current.blur();
                if (onEnter) {
                    onEnter();
                }
            }
            else if (onEsc && key === 'Escape') {
                _this.setState(function () { return ({ wasCancelled: true }); }, onEsc);
                e.preventDefault();
                e.stopPropagation();
            }
            else if (onMove) {
                if (e.shiftKey && key === 'Tab') {
                    _this.blurMoveAndCancel('left', e);
                }
                else if (key === 'Tab') {
                    _this.blurMoveAndCancel('right', e);
                }
                else if (key === 'ArrowUp') {
                    _this.blurMoveAndCancel('up', e);
                }
                else if (key === 'ArrowDown') {
                    _this.blurMoveAndCancel('down', e);
                }
                else if (key === 'ArrowRight') {
                    if (_this.textInput.current.value.length ===
                        _this.textInput.current.selectionStart &&
                        _this.textInput.current.selectionStart ===
                            _this.textInput.current.selectionStart) {
                        _this.blurMoveAndCancel('right', e);
                    }
                }
                else if (key === 'ArrowLeft') {
                    if (_this.textInput.current.selectionStart === 0 &&
                        _this.textInput.current.selectionStart ===
                            _this.textInput.current.selectionStart) {
                        _this.blurMoveAndCancel('left', e);
                    }
                }
            }
            else if (onKeyDown) {
                onKeyDown(e);
            }
        };
        _this.blurMoveAndCancel = function (direction, e) {
            var onMove = _this.props.onMove;
            _this.textInput.current.blur();
            if (onMove) {
                onMove(direction);
            }
            e.preventDefault();
            e.stopPropagation();
        };
        _this.onBlur = function (e) {
            var _a = _this.props, onDone = _a.onDone, onBlur = _a.onBlur;
            var value = e.target.value;
            var wasCancelled = _this.state.wasCancelled;
            if (onDone && !wasCancelled) {
                onDone(value || '');
            }
            if (onBlur) {
                onBlur();
            }
        };
        return _this;
    }
    SimpleTextInputComponent.prototype.componentDidMount = function () {
        var _a = this.props, selectAllOnMount = _a.selectAllOnMount, moveCursorToEndOnMount = _a.moveCursorToEndOnMount;
        if (selectAllOnMount) {
            this.textInput.current.setSelectionRange(0, this.textInput.current.value.length);
        }
        else if (moveCursorToEndOnMount) {
            this.textInput.current.setSelectionRange(this.textInput.current.value.length, this.textInput.current.value.length);
        }
    };
    SimpleTextInputComponent.prototype.componentWillReceiveProps = function (nextProps) {
        var nextValue = nextProps.value;
        var prevValue = this.props.value;
        if (nextValue && nextValue !== prevValue) {
            this.textInput.current.value = nextValue;
        }
    };
    SimpleTextInputComponent.prototype.render = function () {
        var _a = this.props, _b = _a.value, value = _b === void 0 ? '' : _b, width = _a.width, height = _a.height, fontSize = _a.fontSize, maxLength = _a.maxLength, size = _a.size, backgroundColor = _a.backgroundColor, textColor = _a.textColor, placeholder = _a.placeholder, _c = _a.disabled, disabled = _c === void 0 ? false : _c, style = _a.style, className = _a.className, theme = _a.theme, onFocus = _a.onFocus, placeholderColor = _a.placeholderColor, focusOnMount = _a.focusOnMount, selectAllOnMount = _a.selectAllOnMount, _d = _a.inputType, inputType = _d === void 0 ? 'text' : _d, min = _a.min, max = _a.max;
        return (React.createElement(StyledInput, { theme: theme, placeholderColor: placeholderColor, backgroundColor: backgroundColor, textColor: textColor, width: width, height: height, fontSize: fontSize, outerStyle: style, className: className, type: inputType, ref: this.textInput, onKeyDown: this.onKeyDown, onChange: this.onChange, onBlur: this.onBlur, onFocus: onFocus, autoFocus: focusOnMount || selectAllOnMount, value: value, maxLength: maxLength, placeholder: placeholder, size: size, disabled: disabled, min: min, max: max }));
    };
    return SimpleTextInputComponent;
}(React.Component));
exports.SimpleTextInput = recompose_1.compose(WithTheme_1.withTheme)(SimpleTextInputComponent);
//# sourceMappingURL=SimpleTextInput.js.map