"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var recompose_1 = require("recompose");
var lodash_1 = require("lodash");
var withPasteHandler = recompose_1.withHandlers({
    onPasteHandler: function (_a) {
        var onPaste = _a.onPaste;
        return function (e) {
            if (onPaste) {
                var data = e.clipboardData.getData('text');
                if (data != null) {
                    onPaste(data);
                }
                e.preventDefault();
                e.stopPropagation();
            }
        };
    },
    onCopyHandler: function (_a) {
        var onCopy = _a.onCopy;
        return function (e) {
            if (onCopy) {
                var data = typeof onCopy === 'string' ? onCopy : onCopy();
                e.clipboardData.setData('text', data);
                e.preventDefault();
                e.stopPropagation();
            }
        };
    },
});
var withOnPasteProp = recompose_1.withProps(function (_a) {
    var onPasteHandler = _a.onPasteHandler, onCopyHandler = _a.onCopyHandler;
    return ({
        onPaste: onPasteHandler,
        onCopy: onCopyHandler,
    });
});
var omitProps = function (keys) { return recompose_1.mapProps(function (props) { return lodash_1.omit(props, keys); }); };
exports.withCopyPasteListener = function () {
    return recompose_1.compose(withPasteHandler, withOnPasteProp, omitProps(['onPasteHandler', 'onCopyHandler']));
};
exports.withDivCopyPasteListener = exports.withCopyPasteListener();
exports.CopyPasteListener = exports.withCopyPasteListener()(/** @class */ (function (_super) {
    tslib_1.__extends(class_1, _super);
    function class_1() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    class_1.prototype.render = function () {
        var _a = this.props, onPaste = _a.onPaste, onCopy = _a.onCopy;
        return (React.createElement("div", { onPaste: onPaste, onCopy: onCopy }, this.props.children));
    };
    return class_1;
}(React.Component)));
//# sourceMappingURL=CopyPasteListener.js.map