import { FontWeightProperty } from 'csstype';
import * as React from 'react';
export interface TextBaseProps {
    /** The font size of the text. */
    fontSize: string;
    /** The font family of the text. */
    fontFamily: string;
    /** The normal font weight of the text. */
    fontWeightNormal?: FontWeightProperty;
    /** The bold font weight of the text. */
    fontWeightBold: FontWeightProperty;
    /** The light font weight of the text. */
    fontWeightLight: FontWeightProperty;
}
export declare type TextBaseWeight = 'bold' | 'normal' | 'light';
export interface TextBaseSharedProps {
    /** The color family of the text. */
    color?: string;
    /** Disables wrapping of text. */
    nowrap?: boolean;
    /** Adds underline to text. */
    underline?: boolean;
    /**
     * Makes text bold.
     * @deprecated Use prop weight instead.
     */
    bold?: boolean;
    /** Font weight to use. */
    weight?: TextBaseWeight;
    /** Adds underline when mouse hovers over text. */
    hoverUnderline?: boolean;
    /** Makes text italic. */
    italic?: boolean;
    /** Disables the ability to select the text. */
    disableSelect?: boolean;
}
export declare class TextBase extends React.PureComponent<TextBaseProps & TextBaseSharedProps> {
    render(): JSX.Element;
}
