import * as React from 'react';
import { RevertableValue } from './UseRevertableValue';
export declare type AllowedInputType = 'all' | 'numeric' | 'alphanumeric' | 'letters';
declare type OnStartEditingFunc = (keyEvent?: KeyDownEvent) => void;
declare type TransformEnteredValueFunc<TValue> = (value?: string) => TValue;
export interface UseEditableCellOptions<TValue> {
    /**
     * Specifies if cell is editable.
     */
    isEditable?: boolean;
    /**
     * Types of keyboard input that will start editing and pre-fill editor.
     */
    allowedInputType?: AllowedInputType;
    /**
     * Callback that is invoked when editing a cell is started.
     * @param keyEvent
     */
    onStartEditing?: OnStartEditingFunc;
    /**
     * Callback that is invoked when editing a cell stops.
     */
    onStopEditing?: () => void;
    /**
     * Callback that is invoked when editing a cell is finished with a value result.
     * @param value
     */
    onChange?: (value: TValue | undefined) => void;
    /**
     * Transform entered input to TValue.
     * @param value
     */
    transformEnteredValue?: TransformEnteredValueFunc<TValue>;
}
export interface UseEditableCellResult<TValue> {
    onKeyDown: React.KeyboardEventHandler;
    isEditing: boolean;
    startEditing: OnStartEditingFunc;
    stopEditing: () => void;
    stopEditingAndRevert: () => void;
    lastKeyEvent: KeyDownEvent | undefined;
    revertableValue: RevertableValue<TValue>;
    onDoubleClick: () => void;
}
export interface KeyDownEvent {
    altKey: boolean;
    charCode: number;
    ctrlKey: boolean;
    key: string;
    keyCode: number;
    locale: string;
    location: number;
    metaKey: boolean;
    repeat: boolean;
    shiftKey: boolean;
    which: number;
}
export declare const useEditableCell: <TValue>(value: TValue, { isEditable, allowedInputType, onChange, onStartEditing, onStopEditing, transformEnteredValue, }: UseEditableCellOptions<TValue>) => UseEditableCellResult<TValue>;
export {};
