"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var UseRevertableValue_1 = require("./UseRevertableValue");
var createKeyDownEvent = function (event) { return ({
    altKey: event.altKey,
    charCode: event.charCode,
    ctrlKey: event.ctrlKey,
    key: event.key,
    keyCode: event.keyCode,
    locale: event.locale,
    location: event.location,
    metaKey: event.metaKey,
    repeat: event.repeat,
    shiftKey: event.shiftKey,
    which: event.which,
}); };
// tslint:disable-next-line:no-any
var defaultTransformEnteredValue = function (value) { return value; };
exports.useEditableCell = function (value, _a) {
    var _b = _a.isEditable, isEditable = _b === void 0 ? false : _b, _c = _a.allowedInputType, allowedInputType = _c === void 0 ? 'all' : _c, onChange = _a.onChange, onStartEditing = _a.onStartEditing, onStopEditing = _a.onStopEditing, _d = _a.transformEnteredValue, transformEnteredValue = _d === void 0 ? defaultTransformEnteredValue : _d;
    var _e = react_1.useState(false), isEditing = _e[0], setIsEditing = _e[1];
    var _f = react_1.useState(undefined), lastKeyEvent = _f[0], setLastKeyEvent = _f[1];
    var revertableValue = UseRevertableValue_1.useRevertableValue(value);
    var startEditing = react_1.useCallback(function (keyEvent) {
        if (isEditable) {
            setIsEditing(true);
            if (onStartEditing) {
                onStartEditing(keyEvent);
            }
        }
    }, [isEditable, onStartEditing, setIsEditing]);
    var stopEditing = react_1.useCallback(function () {
        if (isEditable) {
            setIsEditing(false);
            if (onStopEditing) {
                onStopEditing();
            }
            if (onChange) {
                onChange(revertableValue.value);
            }
        }
    }, [isEditable, onChange, onStopEditing, revertableValue, setIsEditing]);
    var stopEditingAndRevert = react_1.useCallback(function () {
        if (isEditable) {
            setIsEditing(false);
            if (onStopEditing) {
                onStopEditing();
            }
            revertableValue.revert();
        }
    }, [isEditable, onStopEditing, revertableValue, setIsEditing]);
    var onKeyDown = react_1.useMemo(function () {
        return createKeyDownHandler(isEditing, isEditable, startEditing, setLastKeyEvent, allowedInputType, transformEnteredValue, revertableValue);
    }, [
        isEditing,
        isEditable,
        startEditing,
        setLastKeyEvent,
        allowedInputType,
        transformEnteredValue,
        revertableValue,
    ]);
    return {
        onKeyDown: onKeyDown,
        isEditing: isEditing,
        lastKeyEvent: lastKeyEvent,
        revertableValue: revertableValue,
        startEditing: startEditing,
        stopEditing: stopEditing,
        stopEditingAndRevert: stopEditingAndRevert,
        onDoubleClick: startEditing,
    };
};
var createKeyDownHandler = function (isEditing, isEditable, startEditing, setLastKeyEvent, allowedInputType, transformEnteredValue, revertableValue) { return function (e) {
    if (e.key === 'Enter' && isEditable) {
        setLastKeyEvent(undefined);
        startEditing();
        revertableValue.commit();
        e.preventDefault();
        e.stopPropagation();
    }
    else if (!e.ctrlKey &&
        !e.metaKey &&
        e.key.match(/^[a-zA-Z0-9]$/) &&
        isEditable) {
        // TODO Find nice way to allow full user control, while also providing simplicity.
        var num = parseInt(e.key, 10);
        var lastKeyEvent = createKeyDownEvent(e);
        if (!isNaN(num)) {
            if (allowedInputType === 'all' ||
                allowedInputType === 'numeric' ||
                allowedInputType === 'alphanumeric') {
                startEditing(lastKeyEvent);
                setLastKeyEvent(lastKeyEvent);
                revertableValue.commit();
                revertableValue.setValue(transformEnteredValue(lastKeyEvent.key));
                e.preventDefault();
                e.stopPropagation();
            }
        }
        else if (allowedInputType === 'all' ||
            allowedInputType === 'alphanumeric' ||
            allowedInputType === 'letters') {
            startEditing(lastKeyEvent);
            setLastKeyEvent(lastKeyEvent);
            revertableValue.commit();
            revertableValue.setValue(transformEnteredValue(lastKeyEvent.key));
            e.preventDefault();
            e.stopPropagation();
        }
    }
}; };
//# sourceMappingURL=UseEditableCell.js.map