import { KeyboardEventHandler } from 'react';
import { MoveDirection } from '../util/DirectionCalculator';
import { KeyDownEvent, UseEditableCellOptions } from './UseEditableCell';
import { GridNavigationRequiredProps, UseGridNavigationOptions } from './UseGridNavigation';
export declare type UseGridCellOptions<TValue> = UseGridNavigationOptions & UseEditableCellOptions<TValue>;
export interface UseGridCellResult<TValue> {
    /**
     * The current value in the editor. Pass this as value to form field components.
     */
    editorValue: TValue;
    /**
     * The setter for current value in the editor. Pass this as onChange to form field components.
     * @param editorValue
     */
    setEditorValue: (editorValue: TValue) => void;
    /**
     * Reverts the value of form field to the value before user started editing. This is invoked by stopEditingAndRevert.
     */
    revertEditorValue: () => void;
    /**
     * Props that must be passed to the cell DOM element which can be focused.
     */
    requiredProps: GridCellRequiredProps;
    /**
     * Moves focus to a new cell in the specified direction.
     * @param direction
     */
    move: (direction: MoveDirection) => void;
    /**
     * Opens the editor. invokes onStartEdit if provided.
     */
    startEditing: () => void;
    /**
     * Closes the editor and invokes onChange with the editor value entered by user.
     */
    stopEditing: () => void;
    /**
     * Closes the editor and reverts editor value to the previous value. Does not invoke onChange.
     */
    stopEditingAndRevert: () => void;
    /**
     * Closes the editor and moves focus to a new cell in the specified direction. Invokes onChange with editor value.
     * @param direction
     */
    stopEditingAndMove: (direction: MoveDirection) => void;
    /**
     * True if cell is currently in editing mode.
     */
    isEditing: boolean;
    /**
     * Contains last key event if editor was started by any key other than Enter.
     */
    lastKeyEvent: KeyDownEvent | undefined;
}
export interface GridCellRequiredProps extends Pick<GridNavigationRequiredProps, 'tabIndex' | 'id'> {
    onKeyDown: KeyboardEventHandler;
    onDoubleClick: () => void;
}
/**
 * Hook for cell in a grid. Combines navigation and editable cell.
 * @param value The value of the current cell.
 * @param options Options for hook.
 */
export declare const useGridCell: <TValue>(value: TValue, options: UseGridCellOptions<TValue>) => UseGridCellResult<TValue>;
