"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var react_1 = require("react");
var UseEditableCell_1 = require("./UseEditableCell");
var UseGridNavigation_1 = require("./UseGridNavigation");
var UseGridNavigationOptionsFromContext_1 = require("./UseGridNavigationOptionsFromContext");
// tslint:disable:no-any
/**
 * Hook for cell in a grid. Combines navigation and editable cell.
 * @param value The value of the current cell.
 * @param options Options for hook.
 */
exports.useGridCell = function (value, options) {
    var tableId = UseGridNavigationOptionsFromContext_1.useGridNavigationOptionsFromContext(options).tableId;
    var nav = UseGridNavigation_1.useGridNavigation(options);
    var edit = UseEditableCell_1.useEditableCell(value, options);
    var cellCoordinates = react_1.useMemo(function () { return ({
        rowIndex: options.rowIndex,
        colIndex: options.colIndex,
    }); }, [options.rowIndex, options.colIndex]);
    var startEditing = react_1.useCallback(function () {
        edit.startEditing();
        nav.focusOnCell(tableId, cellCoordinates);
    }, [edit, nav, tableId, cellCoordinates]);
    var stopEditing = react_1.useCallback(function () {
        edit.stopEditing();
        nav.focusOnCell(tableId, cellCoordinates);
    }, [edit, nav, tableId, cellCoordinates]);
    var stopEditingAndRevert = react_1.useCallback(function () {
        edit.stopEditingAndRevert();
        nav.focusOnCell(tableId, cellCoordinates);
    }, [edit, nav, tableId, cellCoordinates]);
    var stopEditingAndMove = react_1.useCallback(function (direction) {
        edit.stopEditing();
        nav.moveHandler(direction);
    }, [edit, nav]);
    var move = react_1.useCallback(function (direction) {
        nav.moveHandler(direction);
    }, [nav]);
    var onKeyDown = react_1.useCallback(function (e) {
        if (!edit.isEditing) {
            var consumed = nav.requiredProps.onKeyDown(e);
            if (!consumed) {
                edit.onKeyDown(e);
            }
        }
    }, [edit, nav.requiredProps]);
    return {
        isEditing: edit.isEditing,
        lastKeyEvent: edit.lastKeyEvent,
        editorValue: edit.revertableValue.value,
        setEditorValue: edit.revertableValue.setValue,
        revertEditorValue: edit.revertableValue.revert,
        requiredProps: tslib_1.__assign({}, nav.requiredProps, { onKeyDown: onKeyDown, onDoubleClick: edit.onDoubleClick }),
        move: move,
        startEditing: startEditing,
        stopEditing: stopEditing,
        stopEditingAndRevert: stopEditingAndRevert,
        stopEditingAndMove: stopEditingAndMove,
    };
};
//# sourceMappingURL=UseGridCell.js.map