import { KeyboardEvent } from 'react';
import { CellIndices, MoveDirection } from '../util/DirectionCalculator';
export interface UseGridNavigationOptions {
    /**
     * The row index for current cell.
     */
    rowIndex: number;
    /**
     * The column index for current cell.
     */
    colIndex: number;
    /**
     * Total number of rows in table. Must be set in cell hook or in GridHooksTable prop.
     */
    numRows?: number;
    /**
     * Total number of columns in table. Must be set in cell hook or in GridHooksTable prop.
     */
    numCols?: number;
    /**
     * An ID for the table, must be unique for every table in page. Must be set in cell hook or in GridHooksTable prop.
     */
    tableId?: string;
    /**
     * If true, navigation will wrap around the table. If false, navigation stops at table edge.
     */
    wrap?: boolean;
    /**
     * Callback that is invoked when user navigates to new cell by keyboard.
     */
    onCellMove?: CellMoveHandler;
    /**
     * Callback that is invoked when user navigates but don't move to new cell by keyboard.
     */
    onCellNavigation?: CellNavigationHandler;
}
export interface ValidatedUseGridNavigationOptions {
    rowIndex: number;
    colIndex: number;
    numRows: number;
    numCols: number;
    tableId: string;
    wrap?: boolean;
    onCellMove?: CellMoveHandler;
    onCellNavigation?: CellNavigationHandler;
}
export interface UseGridNavigationResult {
    requiredProps: GridNavigationRequiredProps;
    moveHandler: MoveHandler;
    focusOnCell: FocusOnCellFunc;
}
/**
 * Props that must be passed to element with focus.
 */
export interface GridNavigationRequiredProps {
    tabIndex: number;
    onKeyDown: (e: KeyboardEvent) => boolean;
    id: string;
}
export declare type CellMoveHandler = (event: OnCellMoveEvent) => void;
export declare type CellNavigationHandler = (event: OnCellNavigationEvent) => void;
export interface OnCellMoveEvent {
    direction: MoveDirection;
    fromRowIndex: number;
    fromColIndex: number;
    rowDidChange: boolean;
    colDidChange: boolean;
    rowIndex: number;
    colIndex: number;
}
export interface OnCellNavigationEvent extends OnCellMoveEvent {
    cellDidChange: boolean;
}
export declare const useGridNavigation: (options: UseGridNavigationOptions) => UseGridNavigationResult;
declare type MoveHandler = (direction: MoveDirection) => void;
declare type FocusOnCellFunc = (tableId: string, pos: CellIndices) => void;
export declare const focusOnCell: FocusOnCellFunc;
export {};
