"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var DirectionCalculator_1 = require("../util/DirectionCalculator");
var DomIdValidator_1 = require("../util/DomIdValidator");
var UseGridNavigationOptionsFromContext_1 = require("./UseGridNavigationOptionsFromContext");
exports.useGridNavigation = function (options) {
    var _a = UseGridNavigationOptionsFromContext_1.useGridNavigationOptionsFromContext(options), rowIndex = _a.rowIndex, colIndex = _a.colIndex, numRows = _a.numRows, numCols = _a.numCols, tableId = _a.tableId, _b = _a.wrap, wrap = _b === void 0 ? false : _b, onCellMove = _a.onCellMove, onCellNavigation = _a.onCellNavigation;
    var moveHandler = react_1.useMemo(function () {
        return createMoveHandler(tableId, rowIndex, colIndex, numRows, numCols, wrap, onCellMove, onCellNavigation);
    }, [
        tableId,
        rowIndex,
        colIndex,
        numRows,
        numCols,
        wrap,
        onCellMove,
        onCellNavigation,
    ]);
    var onKeyDown = react_1.useMemo(function () { return createKeyDownHandler(moveHandler); }, [
        moveHandler,
    ]);
    var id = react_1.useMemo(function () { return createCellId(tableId, rowIndex, colIndex); }, [
        tableId,
        rowIndex,
        colIndex,
    ]);
    return {
        focusOnCell: exports.focusOnCell,
        moveHandler: moveHandler,
        requiredProps: {
            tabIndex: 0,
            onKeyDown: onKeyDown,
            id: id,
        },
    };
};
var createMoveHandler = function (tableId, rowIndex, colIndex, numRows, numCols, wrap, onCellMove, onCellNavigation) { return function (direction) {
    var pos = DirectionCalculator_1.getNextPositionWrappedOrClamped(rowIndex, colIndex, numRows, numCols, direction, wrap);
    var colDidChange = colIndex !== pos.colIndex;
    var rowDidChange = rowIndex !== pos.rowIndex;
    if (colDidChange || rowDidChange) {
        if (onCellMove) {
            onCellMove({
                direction: direction,
                fromRowIndex: rowIndex,
                fromColIndex: colIndex,
                rowIndex: pos.rowIndex,
                colIndex: pos.colIndex,
                colDidChange: colDidChange,
                rowDidChange: rowDidChange,
            });
        }
        exports.focusOnCell(tableId, pos);
    }
    if (onCellNavigation) {
        onCellNavigation({
            direction: direction,
            fromRowIndex: rowIndex,
            fromColIndex: colIndex,
            rowIndex: pos.rowIndex,
            colIndex: pos.colIndex,
            colDidChange: colDidChange,
            rowDidChange: rowDidChange,
            cellDidChange: colDidChange || rowDidChange,
        });
    }
}; };
var createCellId = function (tableId, rowIndex, colIndex) { return DomIdValidator_1.ensureDomIdIsCorrect("table-" + tableId + "-" + rowIndex + "-" + colIndex); };
var createKeyDownHandler = function (moveHandler) { return function (e) {
    if (e.key === 'ArrowLeft') {
        moveHandler('left');
        e.preventDefault();
        e.stopPropagation();
        return true;
    }
    else if (e.key === 'ArrowUp') {
        moveHandler('up');
        e.preventDefault();
        e.stopPropagation();
        return true;
    }
    else if (e.key === 'ArrowRight') {
        moveHandler('right');
        e.preventDefault();
        e.stopPropagation();
        return true;
    }
    else if (e.key === 'ArrowDown') {
        moveHandler('down');
        e.preventDefault();
        e.stopPropagation();
        return true;
    }
    else {
        return false;
    }
}; };
exports.focusOnCell = function (tableId, pos) {
    var el = (document.querySelector("#" + createCellId(tableId, pos.rowIndex, pos.colIndex)) ||
        document.querySelector("#" + createCellId(tableId, pos.rowIndex, pos.colIndex)));
    if (el) {
        el.focus();
    }
};
//# sourceMappingURL=UseGridNavigation.js.map