"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var lodash_1 = require("lodash");
var recompose_1 = require("recompose");
var index_1 = require("../../components/util/enhancers/index");
var OmitProps_1 = require("../../util/enhancers/omit/OmitProps");
var customStyles = function (selectTheme) { return ({
    option: function (base, _a) {
        var isDisabled = _a.isDisabled, isFocused = _a.isFocused, isSelected = _a.isSelected;
        return (tslib_1.__assign({}, base, { fontFamily: selectTheme.input.fontFamily, fontSize: selectTheme.input.fontSize, backgroundColor: isDisabled
                ? selectTheme.menu.disabledBackgroundColor
                : isSelected
                    ? selectTheme.menu.selectedItemBackgroundColor
                    : isFocused
                        ? selectTheme.menu.hoverBackgroundColor
                        : undefined, color: isDisabled
                ? selectTheme.menu.disabledTextColor
                : isSelected
                    ? selectTheme.menu.selectedItemTextColor
                    : isFocused
                        ? selectTheme.menu.hoverTextColor
                        : undefined, cursor: isDisabled ? 'not-allowed' : 'default', whiteSpace: selectTheme.menu.whiteSpace || base.whiteSpace }));
    },
    control: function (base, _a) {
        var isFocused = _a.isFocused, isDisabled = _a.isDisabled;
        return (tslib_1.__assign({}, base, { 
            // none of react-selects styles are passed to <View />
            fontFamily: selectTheme.input.fontFamily, fontSize: selectTheme.input.fontSize, minHeight: selectTheme.input.minHeight, height: selectTheme.input.height, backgroundColor: isDisabled
                ? selectTheme.input.disabledBackgroundColor
                : selectTheme.input.backgroundColor, boxShadow: '0', borderRadius: selectTheme.input.borderRadius, border: isFocused
                ? selectTheme.input.borderFocused
                : selectTheme.input.border, borderColor: isFocused
                ? selectTheme.input.borderColorFocused
                : selectTheme.input.borderColor, '&:hover': {
                border: isFocused
                    ? selectTheme.input.borderFocused
                    : selectTheme.input.border,
                borderColor: isFocused
                    ? selectTheme.input.borderColorFocused
                    : selectTheme.input.borderColor,
            } }));
    },
    singleValue: function (base) { return (tslib_1.__assign({}, base, { fontFamily: selectTheme.input.fontFamily, fontSize: selectTheme.input.fontSize, color: selectTheme.input.textColor })); },
    noOptionsMessage: function (base) { return (tslib_1.__assign({}, base, { fontFamily: selectTheme.input.fontFamily, fontSize: selectTheme.input.fontSize })); },
    input: function (base) { return (tslib_1.__assign({}, base, { fontFamily: selectTheme.input.fontFamily, fontSize: selectTheme.input.fontSize, color: selectTheme.input.textColor })); },
    multiValueLabel: function (base) { return (tslib_1.__assign({}, base, { fontFamily: selectTheme.input.fontFamily, fontSize: selectTheme.input.fontSize, backgroundColor: selectTheme.multiSelect.backgroundColor })); },
    indicatorSeparator: function (base) { return (tslib_1.__assign({}, base, { display: 'none' })); },
    clearIndicator: function (base) { return (tslib_1.__assign({}, base, { color: selectTheme.clearButtonColor.standard, '&:hover': {
            color: selectTheme.clearButtonColor.hover,
        } })); },
    placeholder: function (base) { return (tslib_1.__assign({}, base, { fontFamily: selectTheme.input.fontFamily, fontSize: selectTheme.input.fontSize, color: selectTheme.input.placeholderColor })); },
    container: function (base) { return (tslib_1.__assign({}, base)); },
    dropdownIndicator: function (base, _a) {
        var isFocused = _a.isFocused;
        return (tslib_1.__assign({}, base, { color: isFocused
                ? selectTheme.arrowColor.focused.standard
                : selectTheme.arrowColor.closed.standard, '&:hover': {
                color: isFocused
                    ? selectTheme.arrowColor.focused.hover
                    : selectTheme.arrowColor.closed.hover,
            } }));
    },
    menu: function (base) { return (tslib_1.__assign({}, base, { backgroundColor: selectTheme.menu.backgroundColor, color: selectTheme.menu.textColor, minWidth: selectTheme.menu.minWidth || base.minWidth, zIndex: selectTheme.menu.zIndex, width: selectTheme.menu.width || base.width })); },
    menuPortal: function (base) { return (tslib_1.__assign({}, base, { zIndex: selectTheme.menuPortal.zIndex })); },
    multiValueRemove: function (styles, _a) {
        var data = _a.data;
        return (tslib_1.__assign({}, styles, { margin: '3px', color: selectTheme.multiSelect.removeButtonTextColor, backgroundColor: selectTheme.multiSelect.removeButtonBackgroundColor, ':hover': {
                color: selectTheme.multiSelect.removeButtonHoverTextColor,
                backgroundColor: selectTheme.multiSelect.removeButtonHoverBackgroundColor,
            } }));
    },
    multiValue: function (base) { return (tslib_1.__assign({}, base, { backgroundColor: selectTheme.multiSelect.backgroundColor })); },
    loadingMessage: function (base) { return (tslib_1.__assign({}, base, { color: selectTheme.loadingIndicator.textColor, fontFamily: selectTheme.input.fontFamily, fontSize: selectTheme.input.fontSize })); },
}); };
var mergeStyles = function (themeStyle, userStyle) {
    if (!userStyle) {
        return themeStyle;
    }
    return lodash_1.merge({}, themeStyle, userStyle);
};
var withStyles = function (userStyle) {
    return recompose_1.withProps(function (_a) {
        var theme = _a.theme;
        return ({
            styles: mergeStyles(customStyles(theme), userStyle),
        });
    });
};
exports.createSelect = function (selectComponent, userStyle) {
    return recompose_1.setDisplayName('Select')(recompose_1.compose(index_1.withComponentTheme('Select'), withStyles(userStyle), OmitProps_1.omitProps(['theme']))(selectComponent));
};
exports.createAsyncSelect = function (selectComponent, userStyle) {
    return recompose_1.setDisplayName('AsyncSelect')(recompose_1.compose(index_1.withComponentTheme('Select'), withStyles(userStyle), OmitProps_1.omitProps(['theme']))(selectComponent));
};
//# sourceMappingURL=SelectFactory.js.map