"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var recompose_1 = require("recompose");
var NumberBoundsWrapper_1 = require("../../../util/bounds/NumberBoundsWrapper");
exports.withOnFocus = (function () {
    return recompose_1.withHandlers({
        onFocus: function (_a) {
            var columnIndex = _a.columnIndex, rowIndex = _a.rowIndex, onCellFocus = _a.onCellFocus;
            return function () {
                if (onCellFocus) {
                    onCellFocus({ columnIndex: columnIndex, rowIndex: rowIndex });
                }
            };
        },
    });
})();
exports.withEditingState = recompose_1.compose(recompose_1.withState('isEditing', 'setIsEditing', false), recompose_1.withState('enteredText', 'setEnteredText', undefined));
exports.withEditingHandlers = function (getCellId) {
    return recompose_1.withHandlers({
        onMove: function (_a) {
            var columnIndex = _a.columnIndex, rowIndex = _a.rowIndex, setIsEditing = _a.setIsEditing, numColumns = _a.numColumns, numRows = _a.numRows, onCellMove = _a.onCellMove;
            return function (direction) {
                setIsEditing(false);
                var _a = getIndices(columnIndex, rowIndex, direction), nextColumnIndex = _a.columnIndex, nextRowIndex = _a.rowIndex;
                if (onCellMove) {
                    onCellMove({
                        fromRowIndex: rowIndex,
                        fromColumnIndex: columnIndex,
                        rowIndex: nextRowIndex,
                        columnIndex: nextColumnIndex,
                        columnChange: columnIndex !== nextColumnIndex,
                        rowChange: rowIndex !== nextRowIndex,
                    });
                }
                focusOnCell(getCellId, nextColumnIndex, nextRowIndex, numColumns, numRows);
            };
        },
        onDblClick: function (_a) {
            var setEnteredText = _a.setEnteredText, setIsEditing = _a.setIsEditing, value = _a.value;
            return function () {
                setEnteredText(String(value));
                setIsEditing(true);
            };
        },
        onStartEdit: function (_a) {
            var setEnteredText = _a.setEnteredText, setIsEditing = _a.setIsEditing;
            return function (enteredText) {
                setEnteredText(enteredText);
                setIsEditing(true);
            };
        },
        onDone: function (_a) {
            var setIsEditing = _a.setIsEditing;
            return function () {
                setIsEditing(false);
            };
        },
        onDoneAndStay: function (_a) {
            var setIsEditing = _a.setIsEditing, columnIndex = _a.columnIndex, rowIndex = _a.rowIndex, numColumns = _a.numColumns, numRows = _a.numRows;
            return function () {
                setIsEditing(false);
                focusOnCell(getCellId, columnIndex, rowIndex, numColumns, numRows);
            };
        },
        onEsc: function (_a) {
            var setIsEditing = _a.setIsEditing, columnIndex = _a.columnIndex, rowIndex = _a.rowIndex, numColumns = _a.numColumns, numRows = _a.numRows;
            return function () {
                setIsEditing(false);
                focusOnCell(getCellId, columnIndex, rowIndex, numColumns, numRows);
            };
        },
    });
};
var getIndices = function (columnIndex, rowIndex, direction) {
    if (direction === 'up') {
        return {
            columnIndex: columnIndex,
            rowIndex: rowIndex - 1,
        };
    }
    if (direction === 'down') {
        return {
            columnIndex: columnIndex,
            rowIndex: rowIndex + 1,
        };
    }
    if (direction === 'left') {
        return {
            columnIndex: columnIndex - 1,
            rowIndex: rowIndex,
        };
    }
    if (direction === 'right') {
        return {
            columnIndex: columnIndex + 1,
            rowIndex: rowIndex,
        };
    }
    return {
        columnIndex: columnIndex,
        rowIndex: rowIndex,
    };
};
var focusOnCell = function (getCellId, columnIndex, rowIndex, numColumns, numRows) {
    var _a = NumberBoundsWrapper_1.wrapBounds(columnIndex, rowIndex, numColumns - 1, numRows - 1), col = _a.realX, row = _a.realY;
    var el = (document.querySelector("#" + getCellId(col, row)) ||
        document.querySelector("#" + getCellId(col, row)));
    if (el) {
        el.focus();
    }
};
//# sourceMappingURL=WithEditStateHandler.js.map