"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformNumberTimeToString = function (time) {
    if (time == null) {
        return undefined;
    }
    var timeStr = time.toString();
    if (timeStr.length === 3) {
        return timeStr.substr(0, 1) + ":" + timeStr.substr(1, 2);
    }
    if (timeStr.length === 4) {
        return timeStr.substr(0, 2) + ":" + timeStr.substr(2, 2);
    }
    if (timeStr.length === 2) {
        return "0:" + timeStr;
    }
    if (timeStr.length === 1) {
        return "0:0" + timeStr;
    }
    throw new Error('Invalid time number.');
};
exports.transformTimeStringToNumber = function (time) {
    if (time == null) {
        throw new Error('Time is not set.');
    }
    if (time === '') {
        throw new Error('Time is empty.');
    }
    var parts = time.split(':');
    if (parts.length !== 2) {
        throw new Error('Invalid time.');
    }
    if (parts[1].length !== 2) {
        throw new Error('Invalid time.');
    }
    if (parts[0].length < 1 || parts[0].length > 2) {
        throw new Error('Invalid time.');
    }
    var hours = parseInt(parts[0], 10);
    var minutes = parseInt(parts[1], 10);
    if (isNaN(hours)) {
        throw new Error('Invalid time.');
    }
    if (isNaN(minutes)) {
        throw new Error('Invalid time.');
    }
    if (hours < 0 || hours > 23) {
        throw new Error('Invalid time.');
    }
    if (minutes < 0 || minutes > 59) {
        throw new Error('Invalid time.');
    }
    return hours * 100 + minutes;
};
exports.isValidTimeString = function (time) {
    try {
        exports.transformTimeStringToNumber(time);
        return true;
    }
    catch (e) {
        return false;
    }
};
//# sourceMappingURL=TimeTransformer.js.map